# Copyright 2023-2025 Jeongmin Kang, jarvisNim @ GitHub
# See LICENSE for details.

__author__ = "jarvisNim in GitHub"
__version__ = "0.0.6"


from .base import (
    score_volume_volatility,
    get_stock_history_by_fmp,
    get_stock_history_by_yfinance,
    trend_detector,
    trend_detector_for_series,
    get_working_day_before,
)

from .tech import (
    check_go_upward,
    check_go_downward,
    find_tech_raw_list,
    find_tech_graph_type,
    find_current_slope_degree,
    check_top,
    check_buttom,
    find_decision_long_msg,
    find_decision_short_msg,
    get_tech_yf_hist,   
    get_tech_yf_fin,
    get_tech_yf_stastics,
    get_tech_yf_analysis,
    make_tech_plot,
    sma,
    ema,
    macd,
    adx,
    psar,
    ichmoku,
    rsi,
    stoch,
    roc,
    cci,
    willr,
    ao,
    stochrsi,
    ppo,
    obv,
    pvt,
    pvi,
    cmf,
    vwap,
    adosc,
    mfi,
    kvo,
    nvi,
    atr,
    bbands,
    donchian,
    kc,
    rvi,
)

from .strategy import (
    sma_strategy,
    timing_strategy,
    get_vb_signals,
    show_vb_stategy_result,
    volatility_bollinger_strategy,
    get_reversal_signals,
    show_reversal_stategy_result,
    reversal_strategy,
    trend_following_strategy,
    control_chart_strategy,
    vb_genericAlgo_strategy,
    vb_genericAlgo2_strategy,
    gaSellHoldBuy_strategy,
)

from .korea import (
    get_krx_index_analyse,
    get_krx_sector_analyse,
    get_krx_shorting_investor_volume_by_date,
    get_krx_shorting_investor_value_by_date,
    get_korfia_capital_trends,
    get_korfia_credit_remain,
    get_korfia_stock_market_summary,
    get_korfia_kospi_foregin,
    get_korfia_kosdaq_foregin,
    get_korfia_ticker_name,
    get_korfia_ticker_shortselling,
)




# Copyright 2023-2025 Jeongmin Kang, jarvisNim @ GitHub
# See LICENSE for details.


'''
이 곳에는 import 하는 것이 없는 순수한 데이터 자료론에 의한 데이터 상수값만 존재해야함.
기본 function 들은 base.py 로 가야함.
'''


api_key='0e836827495d195023016a96b5fe6e4a'
bok_key = 'OLSJAN6H7R43WEYUEV5Q'
fmp_key = 'f57bdcaa7d140c9de35806d47fbd2f91'

TIMEFRAMES = ['1day']
TIMEFRAMES2 = ['1min', '1hour', '1day']

ASSETS = ['stock', 'bond', 'commodity', 'cash']
# 보유종목들
MY_TICKERS = {
    'US':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'KR':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],    
    'EU':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'JP':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'CN':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'US':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'DE':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],    
    'IN':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'SG':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
}

# 관심종목들
WATCH_TICKERS = {
    'US':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'KR':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],    
    'EU':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'JP':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'CN':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'US':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'DE':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],    
    'IN':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
    'SG':[{'bond':['TLT']}, {'stock':['SPY','QQQ']}, {'commodity':['GLD']}, {'currency':['UUP']}, ],
}

TECH_LIST = {
            'Trend':['sma','ema','macd','adx','psar','ichmoku',],
            'Momentum':['rsi','stoch','roc','cci','willr','ao','stochrsi','ppo',],
            'Volume':['obv','pvt','pvi','cmf','vwap','adosc','mfi','kvo','nvi',],
            'Volatility':['atr','bbands','donchian','kc','rvi',]
}